pub struct VulkanImage { /* private fields */ }Implementations
Sourceimpl VulkanImage
impl VulkanImage
Sourcepub fn from_raw(
image: Image,
view: ImageView,
layout: ImageLayout,
extent: [u32; 2],
format: Format,
subresource_range: ImageSubresourceRange,
flags: ImageCreateFlags,
usage: ImageUsageFlags,
) -> Self
pub fn from_raw( image: Image, view: ImageView, layout: ImageLayout, extent: [u32; 2], format: Format, subresource_range: ImageSubresourceRange, flags: ImageCreateFlags, usage: ImageUsageFlags, ) -> Self
Describes a borrowed image view. subresource_range must match the range used
to create view; extent is its base mip’s size in pixels and format is
the view format. This does not validate handles or transition image layouts.
pub fn image(self) -> Image
pub fn view(self) -> ImageView
pub fn layout(self) -> ImageLayout
pub fn extent(self) -> [u32; 2]
pub fn format(self) -> Format
pub fn usage(self) -> ImageUsageFlags
pub fn subresource_range(self) -> ImageSubresourceRange
Sourcepub fn from_graph(
image: &Image,
view: ImageViewInfo,
layout: ImageLayout,
) -> Result<Self>
pub fn from_graph( image: &Image, view: ImageViewInfo, layout: ImageLayout, ) -> Result<Self>
Gets a cached graph image view and describes its actual subresource range.
The graph image must outlive GPU evaluation; layout must describe its
state at evaluation time. No layout transitions are recorded here.
Errors
Returns an error if the graph cannot create the requested view.